@@ -234,7 +234,7 @@ class CloudVolume(object):
     the numpy array itself was not downsampled. 
     """
     if not layer_type:
-      if arr.dtype in (np.bool, np.uint32, np.uint64, np.uint16):
+      if arr.dtype in (bool, np.uint32, np.uint64, np.uint16):
         layer_type = 'segmentation'
       elif np.issubdtype(arr.dtype, np.integer) \
                         or np.issubdtype(arr.dtype, np.floating):
